summaryrefslogtreecommitdiffstats
path: root/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
diff options
context:
space:
mode:
Diffstat (limited to 'libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c')
-rw-r--r--libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c b/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
index a4dc17ad..8ee9c748 100644
--- a/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
+++ b/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
@@ -86,7 +86,7 @@ fix_signals (void)
if (act.sa_handler == SIG_DFL)
{
act.sa_handler = SIG_IGN;
- sigemptyset (&act.sa_tqmask);
+ sigemptyset (&act.sa_mask);
act.sa_flags = 0;
sigaction (SIGPIPE, &act, NULL);
}
@@ -337,7 +337,7 @@ pipe_connect_unix (assuan_context_t *ctx,
unsetenv ("_assuan_connection_fd");
execv (name, (char *const *) argv);
/* oops - use the pipe to tell the tqparent about it */
snprintf (errbuf, sizeof(errbuf)-1,
"ERR %d can't exec `%s': %.50s\n",
_assuan_error (ASSUAN_Problem_Starting_Server),
@@ -519,7 +519,7 @@ socketpair_connect (assuan_context_t *ctx,
}
execv (name, (char *const *) argv);
/* oops - use the pipe to tell the tqparent about it */
snprintf (errbuf, sizeof(errbuf)-1,
"ERR %d can't exec `%s': %.50s\n",
_assuan_error (ASSUAN_Problem_Starting_Server),
@@ -865,7 +865,7 @@ assuan_pipe_connect2 (assuan_context_t *ctx,
If NAME as well as ARGV are NULL, no exec is done but the same
process is continued. However all file descriptors are closed and
some special environment variables are set. To let the caller
- detect whether the child or the tqparent continues, the child returns
+ detect whether the child or the parent continues, the child returns
a CTX of NULL. */
assuan_error_t
assuan_pipe_connect_ext (assuan_context_t *ctx,
@@ -337,7 +337,7 @@ pipe_connect_unix (assuan_context_t *ctx,
unsetenv ("_assuan_connection_fd");
execv (name, (char *const *) argv);
- /* oops - use the pipe to tell the tqparent about it */
+ /* oops - use the pipe to tell the parent about it */
snprintf (errbuf, sizeof(errbuf)-1,
"ERR %d can't exec `%s': %.50s\n",
@@ -519,7 +519,7 @@ socketpair_connect (assuan_context_t *ctx,
}
execv (name, (char *const *) argv);
- /* oops - use the pipe to tell the tqparent about it */
+ /* oops - use the pipe to tell the parent about it */
snprintf (errbuf, sizeof(errbuf)-1,
"ERR %d can't exec `%s': %.50s\n",